==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/bean/PurchasesettlementEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.PurchasesettlementdetailEntity;
/**
 * 月度物资采购结算单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_purchasesettlement")
public class PurchasesettlementEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编号
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="project_code")
    private java.lang.String projectCode; // 项目编号
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="demander_id")
    private java.lang.Long demanderId; // 需方id
    @TableField(value="demander_name")
    private java.lang.String demanderName; // 需方名称
    @TableField(value="supplier_id")
    private java.lang.Long supplierId; // 供方id
    @TableField(value="supplier_name")
    private java.lang.String supplierName; // 供方名称
    @TableField(value="settlement_type")
    private java.lang.String settlementType; // 结算类型
    @TableField(value="occurrence_time")
    private java.util.Date occurrenceTime; // 发生时间
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="total_amount")
    private java.math.BigDecimal totalAmount; // 发票总金额
    @TableField(value="settlement_start_time")
    private java.util.Date settlementStartTime; // 结算起始时间
    @TableField(value="settlement_deadline")
    private java.util.Date settlementDeadline; // 结算截至时间
    @TableField(value="cumulative_receipt")
    private java.lang.Integer cumulativeReceipt; // 累计发生收料单
    @TableField(value="recovery_receipt")
    private java.lang.Integer recoveryReceipt; // 收回收料单
    @TableField(value="handle_acceptance")
    private java.lang.Integer handleAcceptance; // 办理验收单
    @TableField(value="provide_invoice")
    private java.lang.Integer provideInvoice; // 提供发票
    @TableField(value="department_agent_id")
    private java.lang.Long departmentAgentId; // 项目部经办人id
    @TableField(value="department_agent_name")
    private java.lang.String departmentAgentName; // 项目部经办人名称
    @TableField(value="department_agent_date")
    private java.util.Date  departmentAgentDate; // 项目部经办时间
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="agent_time")
    private java.util.Date agentTime; // 经办时间
    @TableField(value="monthly_total")
    private java.math.BigDecimal monthlyTotal; // 本月合计(除税)
    @TableField(value="tax_monthly_total")
    private java.math.BigDecimal taxMonthlyTotal; // 本月合计(含税)
    @TableField(value="occurrence_total")
    private java.math.BigDecimal occurrenceTotal; // 累计发生(除税)
    @TableField(value="tax_occurrence_total")
    private java.math.BigDecimal taxOccurrenceTotal; // 累计发生(含税)

    @TableField(value="is_reference")
    private java.lang.Integer isReference; // 是否被引用: 0否,1是

    
    @TableField(exist=false)
    @SubEntity(serviceName="purchasesettlementdetailService",pidName = "mid")
    private List<PurchasesettlementdetailEntity> purchasesettlementdetailEntities = new ArrayList<>(); // 月度物资采购结算单子表
    

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目编号
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编号
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 需方id
     */
    public java.lang.Long getDemanderId() {
        return demanderId;
    }

    /**
     * 需方id
     */
    public void setDemanderId(java.lang.Long demanderId) {
        this.demanderId = demanderId;
    }
    /**
     * 需方名称
     */
    public java.lang.String getDemanderName() {
        return demanderName;
    }

    /**
     * 需方名称
     */
    public void setDemanderName(java.lang.String demanderName) {
        this.demanderName = demanderName;
    }
    /**
     * 供方id
     */
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 供方id
     */
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供方名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供方名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 结算类型
     */
    public java.lang.String getSettlementType() {
        return settlementType;
    }

    /**
     * 结算类型
     */
    public void setSettlementType(java.lang.String settlementType) {
        this.settlementType = settlementType;
    }
    /**
     * 发生时间
     */
    public java.util.Date getOccurrenceTime() {
        return occurrenceTime;
    }

    /**
     * 发生时间
     */
    public void setOccurrenceTime(java.util.Date occurrenceTime) {
        this.occurrenceTime = occurrenceTime;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 发票总金额
     */
    public java.math.BigDecimal getTotalAmount() {
        return totalAmount;
    }

    /**
     * 发票总金额
     */
    public void setTotalAmount(java.math.BigDecimal totalAmount) {
        this.totalAmount = totalAmount;
    }
    /**
     * 结算起始时间
     */
    public java.util.Date getSettlementStartTime() {
        return settlementStartTime;
    }

    /**
     * 结算起始时间
     */
    public void setSettlementStartTime(java.util.Date settlementStartTime) {
        this.settlementStartTime = settlementStartTime;
    }
    /**
     * 结算截至时间
     */
    public java.util.Date getSettlementDeadline() {
        return settlementDeadline;
    }

    /**
     * 结算截至时间
     */
    public void setSettlementDeadline(java.util.Date settlementDeadline) {
        this.settlementDeadline = settlementDeadline;
    }
    /**
     * 累计发生收料单
     */
    public java.lang.Integer getCumulativeReceipt() {
        return cumulativeReceipt;
    }

    /**
     * 累计发生收料单
     */
    public void setCumulativeReceipt(java.lang.Integer cumulativeReceipt) {
        this.cumulativeReceipt = cumulativeReceipt;
    }
    /**
     * 收回收料单
     */
    public java.lang.Integer getRecoveryReceipt() {
        return recoveryReceipt;
    }

    /**
     * 收回收料单
     */
    public void setRecoveryReceipt(java.lang.Integer recoveryReceipt) {
        this.recoveryReceipt = recoveryReceipt;
    }
    /**
     * 办理验收单
     */
    public java.lang.Integer getHandleAcceptance() {
        return handleAcceptance;
    }

    /**
     * 办理验收单
     */
    public void setHandleAcceptance(java.lang.Integer handleAcceptance) {
        this.handleAcceptance = handleAcceptance;
    }
    /**
     * 提供发票
     */
    public java.lang.Integer getProvideInvoice() {
        return provideInvoice;
    }

    /**
     * 提供发票
     */
    public void setProvideInvoice(java.lang.Integer provideInvoice) {
        this.provideInvoice = provideInvoice;
    }
    /**
     * 项目部经办人id
     */
    public java.lang.Long getdepartmentAgentId() {
        return departmentAgentId;
    }

    /**
     * 项目部经办人id
     */
    public void setdepartmentAgentId(java.lang.Long departmentAgentId) {
        this.departmentAgentId = departmentAgentId;
    }
    /**
     * 项目部经办人名称
     */
    public java.lang.String getdepartmentAgentName() {
        return departmentAgentName;
    }

    /**
     * 项目部经办人名称
     */
    public void setdepartmentAgentName(java.lang.String departmentAgentName) {
        this.departmentAgentName = departmentAgentName;
    }
    /**
     * 项目部经办时间
     */
    public java.util.Date getdepartmentAgentDate() {
        return departmentAgentDate;
    }

    /**
     * 项目部经办时间
     */
    public void setdepartmentAgentDate(java.util.Date departmentAgentDate) {
        this.departmentAgentDate = departmentAgentDate;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 经办时间
     */
    public java.util.Date getAgentTime() {
        return agentTime;
    }

    /**
     * 经办时间
     */
    public void setAgentTime(java.util.Date agentTime) {
        this.agentTime = agentTime;
    }
    /**
     * 本月合计(除税)
     */
    public java.math.BigDecimal getMonthlyTotal() {
        return monthlyTotal;
    }

    /**
     * 本月合计(除税)
     */
    public void setMonthlyTotal(java.math.BigDecimal monthlyTotal) {
        this.monthlyTotal = monthlyTotal;
    }
    /**
     * 本月合计(含税)
     */
    public java.math.BigDecimal getTaxMonthlyTotal() {
        return taxMonthlyTotal;
    }

    /**
     * 本月合计(含税)
     */
    public void setTaxMonthlyTotal(java.math.BigDecimal taxMonthlyTotal) {
        this.taxMonthlyTotal = taxMonthlyTotal;
    }
    /**
     * 累计发生(除税)
     */
    public java.math.BigDecimal getOccurrenceTotal() {
        return occurrenceTotal;
    }

    /**
     * 累计发生(除税)
     */
    public void setOccurrenceTotal(java.math.BigDecimal occurrenceTotal) {
        this.occurrenceTotal = occurrenceTotal;
    }
    /**
     * 累计发生(含税)
     */
    public java.math.BigDecimal getTaxOccurrenceTotal() {
        return taxOccurrenceTotal;
    }

    /**
     * 累计发生(含税)
     */
    public void setTaxOccurrenceTotal(java.math.BigDecimal taxOccurrenceTotal) {
        this.taxOccurrenceTotal = taxOccurrenceTotal;
    }
    
    /**
     * 月度物资采购结算单子表
     */
    public List<PurchasesettlementdetailEntity> getPurchasesettlementdetailEntities() {
        return purchasesettlementdetailEntities;
    }

    /**
     * 月度物资采购结算单子表
     */
    public void setPurchasesettlementdetailEntities(List<PurchasesettlementdetailEntity> purchasesettlementdetailEntities) {
        this.purchasesettlementdetailEntities = purchasesettlementdetailEntities;
    }

    /**
     *
     * 是否被引用
     */
    public Integer getIsReference() {
        return isReference;
    }

    /**
     * 是否被引用
     * @param isReference
     */
    public void setIsReference(Integer isReference) {
        this.isReference = isReference;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20221014.034307-161-sources.jar: com/ejianc/business/middlemeasurement/bean/PurchasesettlementEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.PurchasesettlementdetailEntity;
/**
 * 月度物资采购结算单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_purchasesettlement")
public class PurchasesettlementEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编号
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="project_code")
    private java.lang.String projectCode; // 项目编号
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="demander_id")
    private java.lang.Long demanderId; // 需方id
    @TableField(value="demander_name")
    private java.lang.String demanderName; // 需方名称
    @TableField(value="supplier_id")
    private java.lang.Long supplierId; // 供方id
    @TableField(value="supplier_name")
    private java.lang.String supplierName; // 供方名称
    @TableField(value="settlement_type")
    private java.lang.String settlementType; // 结算类型
    @TableField(value="occurrence_time")
    private java.util.Date occurrenceTime; // 发生时间
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="total_amount")
    private java.math.BigDecimal totalAmount; // 发票总金额
    @TableField(value="settlement_start_time")
    private java.util.Date settlementStartTime; // 结算起始时间
    @TableField(value="settlement_deadline")
    private java.util.Date settlementDeadline; // 结算截至时间
    @TableField(value="cumulative_receipt")
    private java.lang.Integer cumulativeReceipt; // 累计发生收料单
    @TableField(value="recovery_receipt")
    private java.lang.Integer recoveryReceipt; // 收回收料单
    @TableField(value="handle_acceptance")
    private java.lang.Integer handleAcceptance; // 办理验收单
    @TableField(value="provide_invoice")
    private java.lang.Integer provideInvoice; // 提供发票
    @TableField(value="department_agent_id")
    private java.lang.Long departmentAgentId; // 项目部经办人id
    @TableField(value="department_agent_name")
    private java.lang.String departmentAgentName; // 项目部经办人名称
    @TableField(value="department_agent_date")
    private java.util.Date  departmentAgentDate; // 项目部经办时间
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="agent_time")
    private java.util.Date agentTime; // 经办时间
    @TableField(value="monthly_total")
    private java.math.BigDecimal monthlyTotal; // 本月合计(除税)
    @TableField(value="tax_monthly_total")
    private java.math.BigDecimal taxMonthlyTotal; // 本月合计(含税)
    @TableField(value="occurrence_total")
    private java.math.BigDecimal occurrenceTotal; // 累计发生(除税)
    @TableField(value="tax_occurrence_total")
    private java.math.BigDecimal taxOccurrenceTotal; // 累计发生(含税)

    @TableField(value="is_reference")
    private java.lang.Integer isReference; // 是否被引用: 0否,1是

    @TableField(value="reference_code")
    private java.lang.String referenceCode; // 引用租赁单的汇总单code

    @TableField(value="save_time")
    private java.util.Date saveTime; // 保存时间

    @TableField(exist = false)
    private java.lang.String sort;
    @TableField(exist = false)
    private java.lang.String billStateStr;
    @TableField(exist = false)
    private java.lang.String agentTimeShow;
    @TableField(exist = false)
    private java.lang.String settlementStartTimeShow;
    @TableField(exist = false)
    private java.lang.String settlementDeadlineShow;
    @TableField(exist = false)
    private java.lang.String departmentAgentDateShow;

    
    @TableField(exist=false)
    @SubEntity(serviceName="purchasesettlementdetailService",pidName = "mid")
    private List<PurchasesettlementdetailEntity> purchasesettlementdetailEntities = new ArrayList<>(); // 月度物资采购结算单子表

    public String getReferenceCode() {
        return referenceCode;
    }

    public void setReferenceCode(String referenceCode) {
        this.referenceCode = referenceCode;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public String getAgentTimeShow() {
        return agentTimeShow;
    }

    public void setAgentTimeShow(String agentTimeShow) {
        this.agentTimeShow = agentTimeShow;
    }

    public String getSettlementStartTimeShow() {
        return settlementStartTimeShow;
    }

    public void setSettlementStartTimeShow(String settlementStartTimeShow) {
        this.settlementStartTimeShow = settlementStartTimeShow;
    }

    public String getSettlementDeadlineShow() {
        return settlementDeadlineShow;
    }

    public void setSettlementDeadlineShow(String settlementDeadlineShow) {
        this.settlementDeadlineShow = settlementDeadlineShow;
    }

    public String getDepartmentAgentDateShow() {
        return departmentAgentDateShow;
    }

    public void setDepartmentAgentDateShow(String departmentAgentDateShow) {
        this.departmentAgentDateShow = departmentAgentDateShow;
    }

    public Date getSaveTime() {
        return saveTime;
    }

    public void setSaveTime(Date saveTime) {
        this.saveTime = saveTime;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目编号
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编号
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 需方id
     */
    public java.lang.Long getDemanderId() {
        return demanderId;
    }

    /**
     * 需方id
     */
    public void setDemanderId(java.lang.Long demanderId) {
        this.demanderId = demanderId;
    }
    /**
     * 需方名称
     */
    public java.lang.String getDemanderName() {
        return demanderName;
    }

    /**
     * 需方名称
     */
    public void setDemanderName(java.lang.String demanderName) {
        this.demanderName = demanderName;
    }
    /**
     * 供方id
     */
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 供方id
     */
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供方名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供方名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 结算类型
     */
    public java.lang.String getSettlementType() {
        return settlementType;
    }

    /**
     * 结算类型
     */
    public void setSettlementType(java.lang.String settlementType) {
        this.settlementType = settlementType;
    }
    /**
     * 发生时间
     */
    public java.util.Date getOccurrenceTime() {
        return occurrenceTime;
    }

    /**
     * 发生时间
     */
    public void setOccurrenceTime(java.util.Date occurrenceTime) {
        this.occurrenceTime = occurrenceTime;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 发票总金额
     */
    public java.math.BigDecimal getTotalAmount() {
        return totalAmount;
    }

    /**
     * 发票总金额
     */
    public void setTotalAmount(java.math.BigDecimal totalAmount) {
        this.totalAmount = totalAmount;
    }
    /**
     * 结算起始时间
     */
    public java.util.Date getSettlementStartTime() {
        return settlementStartTime;
    }

    /**
     * 结算起始时间
     */
    public void setSettlementStartTime(java.util.Date settlementStartTime) {
        this.settlementStartTime = settlementStartTime;
    }
    /**
     * 结算截至时间
     */
    public java.util.Date getSettlementDeadline() {
        return settlementDeadline;
    }

    /**
     * 结算截至时间
     */
    public void setSettlementDeadline(java.util.Date settlementDeadline) {
        this.settlementDeadline = settlementDeadline;
    }
    /**
     * 累计发生收料单
     */
    public java.lang.Integer getCumulativeReceipt() {
        return cumulativeReceipt;
    }

    /**
     * 累计发生收料单
     */
    public void setCumulativeReceipt(java.lang.Integer cumulativeReceipt) {
        this.cumulativeReceipt = cumulativeReceipt;
    }
    /**
     * 收回收料单
     */
    public java.lang.Integer getRecoveryReceipt() {
        return recoveryReceipt;
    }

    /**
     * 收回收料单
     */
    public void setRecoveryReceipt(java.lang.Integer recoveryReceipt) {
        this.recoveryReceipt = recoveryReceipt;
    }
    /**
     * 办理验收单
     */
    public java.lang.Integer getHandleAcceptance() {
        return handleAcceptance;
    }

    /**
     * 办理验收单
     */
    public void setHandleAcceptance(java.lang.Integer handleAcceptance) {
        this.handleAcceptance = handleAcceptance;
    }
    /**
     * 提供发票
     */
    public java.lang.Integer getProvideInvoice() {
        return provideInvoice;
    }

    /**
     * 提供发票
     */
    public void setProvideInvoice(java.lang.Integer provideInvoice) {
        this.provideInvoice = provideInvoice;
    }
    /**
     * 项目部经办人id
     */
    public java.lang.Long getdepartmentAgentId() {
        return departmentAgentId;
    }

    /**
     * 项目部经办人id
     */
    public void setdepartmentAgentId(java.lang.Long departmentAgentId) {
        this.departmentAgentId = departmentAgentId;
    }
    /**
     * 项目部经办人名称
     */
    public java.lang.String getdepartmentAgentName() {
        return departmentAgentName;
    }

    /**
     * 项目部经办人名称
     */
    public void setdepartmentAgentName(java.lang.String departmentAgentName) {
        this.departmentAgentName = departmentAgentName;
    }
    /**
     * 项目部经办时间
     */
    public java.util.Date getdepartmentAgentDate() {
        return departmentAgentDate;
    }

    /**
     * 项目部经办时间
     */
    public void setdepartmentAgentDate(java.util.Date departmentAgentDate) {
        this.departmentAgentDate = departmentAgentDate;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 经办时间
     */
    public java.util.Date getAgentTime() {
        return agentTime;
    }

    /**
     * 经办时间
     */
    public void setAgentTime(java.util.Date agentTime) {
        this.agentTime = agentTime;
    }
    /**
     * 本月合计(除税)
     */
    public java.math.BigDecimal getMonthlyTotal() {
        return monthlyTotal;
    }

    /**
     * 本月合计(除税)
     */
    public void setMonthlyTotal(java.math.BigDecimal monthlyTotal) {
        this.monthlyTotal = monthlyTotal;
    }
    /**
     * 本月合计(含税)
     */
    public java.math.BigDecimal getTaxMonthlyTotal() {
        return taxMonthlyTotal;
    }

    /**
     * 本月合计(含税)
     */
    public void setTaxMonthlyTotal(java.math.BigDecimal taxMonthlyTotal) {
        this.taxMonthlyTotal = taxMonthlyTotal;
    }
    /**
     * 累计发生(除税)
     */
    public java.math.BigDecimal getOccurrenceTotal() {
        return occurrenceTotal;
    }

    /**
     * 累计发生(除税)
     */
    public void setOccurrenceTotal(java.math.BigDecimal occurrenceTotal) {
        this.occurrenceTotal = occurrenceTotal;
    }
    /**
     * 累计发生(含税)
     */
    public java.math.BigDecimal getTaxOccurrenceTotal() {
        return taxOccurrenceTotal;
    }

    /**
     * 累计发生(含税)
     */
    public void setTaxOccurrenceTotal(java.math.BigDecimal taxOccurrenceTotal) {
        this.taxOccurrenceTotal = taxOccurrenceTotal;
    }
    
    /**
     * 月度物资采购结算单子表
     */
    public List<PurchasesettlementdetailEntity> getPurchasesettlementdetailEntities() {
        return purchasesettlementdetailEntities;
    }

    /**
     * 月度物资采购结算单子表
     */
    public void setPurchasesettlementdetailEntities(List<PurchasesettlementdetailEntity> purchasesettlementdetailEntities) {
        this.purchasesettlementdetailEntities = purchasesettlementdetailEntities;
    }

    /**
     *
     * 是否被引用
     */
    public Integer getIsReference() {
        return isReference;
    }

    /**
     * 是否被引用
     * @param isReference
     */
    public void setIsReference(Integer isReference) {
        this.isReference = isReference;
    }
}
